﻿using System;
using System.Collections.Generic;

using Eco.Handles;
using Eco.ObjectRepresentation;
using Eco.Services;

using EcoMvcExample.Model;
using Adecs.Eco.Helpers;


namespace EcoMvcExample.MvcWebsite.Models
{
    public static class TaskUserHelper
    {
        public static TaskUser GetUser(IEcoServiceProvider ecoProvider, string UserName)
        {
            if (ecoProvider == null)
                throw new ArgumentNullException("ecoProvider");
            if (UserName == null)
                throw new ArgumentNullException("UserName");

            // Get the specified user
            IVariableFactoryService vfs = ecoProvider.GetEcoService<IVariableFactoryService>();
            IModifiableVariableList mvl = vfs.CreateVariableList();
            mvl.AddConstant("vUserName", UserName);

            // Return a list of the Tasks by specific user
            GeneralObjectRetrieval gor = new GeneralObjectRetrieval(ecoProvider);
            IList<TaskUser> users = gor.GetObjectsMatchingCriteria<TaskUser>("->select(tu | tu.Username = vUserName)", mvl);
            if (users == null)
            {
                throw new ArgumentNullException("users");
            }
            else
            {
                if (users.Count > 0)
                {
                    TaskUser user = users[0];
                    return user;
                }
                else
                {
                    return null;
                }
            }
        }

        public static ExpressionHandle GetAllUsers(IEcoServiceProvider ecoProvider)
        {
            /// Use Handles to return the appropriate list this time.
            /// 

            ReferenceHandle rhRoot = new ReferenceHandle();
            rhRoot.EcoSpaceTypeName = "EcoMvcExample.EcoMvcExampleEcoSpace";
            rhRoot.EcoSpaceType = typeof(EcoMvcExampleEcoSpace);
            rhRoot.EcoSpace = EcoHelper.GetEcospace();

            ExpressionHandle ehAllUsers = new ExpressionHandle();
            ehAllUsers.RootHandle = rhRoot;
            ehAllUsers.AddExternalId = true;
            ehAllUsers.AddSelfColumn = true;
            ehAllUsers.Expression = "TaskUser.allInstances";
            ehAllUsers.Enabled = true;

            ehAllUsers.EnsureBindingList();

            return ehAllUsers;

            /*
            IElement el = ehAllUsers.Element;
            if (el is IElementCollection)
            {
                return el as IElementCollection;
            }
            else
                return null; */

            /*
            if (ecoProvider == null)
                throw new ArgumentNullException("ecoProvider");

            // Return a list of the Tasks by specific user
            GeneralObjectRetrieval gor = new GeneralObjectRetrieval(ecoProvider);
            IList<TaskUser> users = gor.GetObjects<TaskUser>();
            return users; */
        }
    }
}
